// Prevent "more" messages from appearing
   set more off
// Control line length
   set linesize 150

********************************************************************************
******//           BEGIN DATA MANIPULATION OF CHAPTER 5 EXAMPLE           *******
****//                 CHANGE "filesave" to your directory                *******
********************************************************************************

// Defining global variable for file location to be replaced in code below
   global filesave "C:\Dropbox\21_PSQF7375_Longitudinal\PSQF7375_Longitudinal_Example5"

// Import chapter 5 stacked data and center time at first occasion
   use "$filesave\STATA_Chapter5.dta", clear
   gen time = wave - 1
   label variable time "time: Time in Study (0=1)"

********************************************************************************
******//                     BEGIN CHAPTER 5 MODELS                       *******
********************************************************************************

// Save results to separate file
log using $filesave\STATA_Chapter5_Output.log, replace name(STATA_Chapter5)

display "STATA Chapter 5 Example: Get Variance of Time Predictor (=1.263)"
summarize wave, detail

display "STATA Ch 5: Saturated Means, Unstructured Variance Model"
display "ANSWER KEY for both sides of the model"
mixed outcome ib(last).wave, || personid: , noconstant variance reml  ///
          residuals(unstructured,t(wave)) dfmethod(satterthwaite) dftable(pvalue)
      estat ic, n(25)                  // AIC and BIC
      estat wcorrelation, covariance   // R matrix
      estat wcorrelation               // RCORR matrix
      contrast i.wave, small           // Omnibus F-test for wave 
      margins  i.wave                  // Means per wave 
      margins  i.wave, pwcompare(pveffects) df(24)  // Mean diffs by wave
       
display "STATA Ch 5: Saturated Means, Random Intercept Model"
display "ANSWER KEY for means side only"
mixed outcome ib(last).wave, || personid: , variance reml  ///
          residuals(independent,t(wave)) dfmethod(satterthwaite) dftable(pvalue)
      estat ic, n(25)                  // AIC and BIC
      estat icc                        // Conditional intraclass correlation
      estat wcorrelation, covariance   // R matrix
      estat wcorrelation               // RCORR matrix
      contrast i.wave, small           // Omnibus F-test for wave 
      margins  i.wave                  // Means per wave 
      margins  i.wave, pwcompare(pveffects) df(72)  // Mean diffs by wave
       
display "STATA Eq 5.1: Empty Means, Random Intercept Model"
mixed outcome , || personid: , variance reml covariance(unstructured) ///
          residuals(independent,t(wave)) dfmethod(satterthwaite) dftable(pvalue)
      estat ic, n(25)                        // AIC and BIC
      estat icc                              // Intraclass correlation
      estat recovariance, relevel(personid)  // G matrix
      estat wcorrelation, covariance         // V matrix
      estat wcorrelation                     // VCORR matrix

display "STATA Eq 5.3: Fixed Linear Time, Random Intercept Model"
mixed outcome c.time, || personid: , variance reml ///
          residuals(independent,t(wave)) dfmethod(satterthwaite) dftable(pvalue)
      estat ic, n(25)                        // AIC and BIC
      estat recovariance, relevel(personid)  // G matrix
      estat wcorrelation, covariance         // V matrix
      estat wcorrelation                     // VCORR matrix
      lincom _cons*1 + c.time*0, small   // Intercept at Time=0
      lincom _cons*1 + c.time*1, small   // Intercept at Time=1
      lincom _cons*1 + c.time*2, small   // Intercept at Time=2
      lincom _cons*1 + c.time*3, small   // Intercept at Time=3
      estimates store FitFixLin          // Save for LRT

display "STATA Eq 5.5: Random Linear Time Model"
mixed outcome c.time, || personid: time, variance reml covariance(unstructured) ///
          residuals(independent,t(wave)) dfmethod(satterthwaite) dftable(pvalue)
      estat ic, n(25)                                    // AIC and BIC
      estat recovariance, relevel(personid)              // G matrix
      estat recovariance, relevel(personid) correlation  // GCORR matrix
      estat wcorrelation, covariance                     // V matrix
      estat wcorrelation                                 // VCORR matrix
      lincom _cons*1 + c.time*0, small   // Intercept at Time=0
      lincom _cons*1 + c.time*1, small   // Intercept at Time=1
      lincom _cons*1 + c.time*2, small   // Intercept at Time=2
      lincom _cons*1 + c.time*3, small   // Intercept at Time=3
      estimates store FitRandLin         // Save for LRT
      lrtest FitRandLin FitFixLin        // Does random linear time slope improve fit?

display "STATA Ch 5: Random Linear Time Model with AR1 R Matrix"
mixed outcome c.time,  || personid: time, variance reml covariance(unstructured) ///
          residuals(ar1,t(wave)) dfmethod(satterthwaite) dftable(pvalue)
      estat ic, n(25)                                    // AIC and BIC
      estat recovariance, relevel(personid)              // G matrix
      estat recovariance, relevel(personid) correlation  // GCORR matrix
      estat wcorrelation, covariance                     // V matrix
      estat wcorrelation                                 // VCORR matrix
      estimates store FitRandLinAR1    // Save for LRT
      lrtest FitRandLinAR1 FitRandLin  // Does AR1 residual correlation improve fit?

display "STATA Ch 5: Random Linear Time Model with TOEP2 R Matrix"
mixed outcome c.time, || personid: time, variance reml covariance(unstructured) ///
          residuals(toeplitz1,t(wave)) dfmethod(satterthwaite) dftable(pvalue)
      estat ic, n(25)                                    // AIC and BIC
      estat recovariance, relevel(personid)              // G matrix
      estat recovariance, relevel(personid) correlation  // GCORR matrix
      estat wcorrelation, covariance                     // V matrix
      estat wcorrelation                                 // VCORR matrix
      estimates store FitRandLinTOEP2   // Save for LRT
      lrtest FitRandLinTOEP2 FitRandLin // Does lag-1 residual correlation improve fit? 
 
***** END CHAPTER 5 MODELS ******

// Close log
   log close STATA_Chapter5
